from aws_cdk import (
    core,
    aws_certificatemanager as acm,
    aws_ec2 as ec2,
    aws_events as events,
    aws_events_targets as targets,
    aws_lambda as _lambda,
    aws_logs as logs,
    aws_route53 as route53,
    aws_s3 as s3,
)
from typing import Optional, List

from acru_l.resources.apigateway import LambdaAPIGateway
from acru_l.resources.canary import Canary
from acru_l.resources.custom_resources import CustomResource
from acru_l.resources.functions import Function
from acru_l.stacks.config import (
    SecretsConfig,
    CustomResourceConfig,
    CanaryConfig,
)


class Service(core.Construct):

    pre_deploy: Optional[CustomResource] = None
    post_deploy: Optional[CustomResource] = None
    canary: Optional[Canary]
    layers: List[_lambda.LayerVersion]
    api_lambda: Function
    apigw: LambdaAPIGateway

    def __init__(
        self,
        scope: core.Construct,
        id: str,
        *,
        domain_name: str,
        project_source_path: str,
        api_lambda_source_path: str,
        certificate: acm.Certificate,
        hosted_zone: route53.HostedZone,
        runtime: _lambda.Runtime = _lambda.Runtime.PYTHON_3_8,
        vpc: Optional[ec2.Vpc] = None,
        environment_variables: Optional[dict] = None,
        secrets: Optional[List[SecretsConfig]] = None,
        secret_arns: Optional[List] = None,
        function_class=Function,
        pre_deploy_config: CustomResourceConfig,
        post_deploy_config: CustomResourceConfig,
        canary_config: CanaryConfig,
    ):
        super().__init__(scope, id)
        self.function_class = function_class
        self.private_bucket = s3.Bucket(
            self, "PrivateBucket", public_read_access=False
        )
        self.vpc = vpc
        self.runtime = runtime
        self.environment_variables = environment_variables or {}
        self.secret_arns = secret_arns or []

        self.setup_environment(secrets=secrets)
        self.layers = self.package_project(source_path=project_source_path)

        self.add_pre_deploy(config=pre_deploy_config)
        self.add_api(
            api_lambda_source_path=api_lambda_source_path,
            domain_name=domain_name,
            certificate=certificate,
            hosted_zone=hosted_zone,
        )
        self.add_canary(config=canary_config)
        self.add_post_deploy(config=post_deploy_config)

    def setup_environment(self, *, secrets: Optional[List[SecretsConfig]]):
        secrets = secrets or []
        for secrets_config in secrets:
            _secret = secrets_config.create(scope=self)
            envvar_id = f"{secrets_config.arn_key.upper()}_ID"
            self.secret_arns.append(_secret.secret_arn)
            self.environment_variables[envvar_id] = _secret.secret_arn

    def package_project(
        self, *, source_path: str
    ) -> List[_lambda.LayerVersion]:
        project_layer = _lambda.LayerVersion(
            self,
            "ProjectLayer",
            code=_lambda.Code.from_asset(source_path),
            compatible_runtimes=[self.runtime],
        )
        return [project_layer]

    def make_function(self, name: str, **kwargs):
        return self.function_class(
            self,
            name,
            layers=self.layers,
            private_bucket=self.private_bucket,
            secret_arns=self.secret_arns,
            environment_variables=self.environment_variables,
            vpc=self.vpc,
            runtime=self.runtime,
            **kwargs,
        )

    def add_api(
        self,
        *,
        api_lambda_source_path: str,
        domain_name: str,
        certificate: acm.Certificate,
        hosted_zone: route53.HostedZone,
    ):
        self.api_lambda = self.make_function(
            "MainLambda",
            source_path=api_lambda_source_path,
            profiling=True,
            tracing=_lambda.Tracing.ACTIVE,
            log_retention=logs.RetentionDays.THREE_MONTHS,
        )
        if self.pre_deploy:
            self.api_lambda.handler.node.add_dependency(
                self.pre_deploy.resource
            )

        keep_warm = events.Rule(
            self, "KeepWarm", schedule=events.Schedule.cron(minute="*/5")
        )
        keep_warm.add_target(
            targets.LambdaFunction(handler=self.api_lambda.handler)
        )

        self.apigw = LambdaAPIGateway(
            self,
            "APIGW",
            domain_name=domain_name,
            certificate=certificate,
            handler=self.api_lambda.handler,
            hosted_zone=hosted_zone,
        )

    def add_canary(self, *, config: CanaryConfig):
        self.canary = Canary(
            self,
            "Canary",
            commit_sha=config.commit_sha,
            version=config.version,
            health_check_url=config.health_check_url,
        )
        self.canary.add_dependency(self.api_lambda.handler)

    def add_pre_deploy(self, *, config: CustomResourceConfig):
        pre_deploy_lambda = self.make_function(
            "PreDeployLambda", source_path=config.source_path
        )

        self.pre_deploy = CustomResource(
            self,
            "PreDeploy",
            on_event_handler=pre_deploy_lambda.handler,
            resource_properties=config.properties,
        )

    def add_post_deploy(self, *, config: CustomResourceConfig):
        post_deploy_lambda = self.make_function(
            "PostDeployLambda", source_path=config.source_path
        )

        self.post_deploy = CustomResource(
            self,
            "PostDeploy",
            on_event_handler=post_deploy_lambda.handler,
            resource_properties=config.properties,
        )
        if self.canary:
            self.post_deploy.resource.node.add_dependency(self.canary.resource)
        else:
            self.post_deploy.resource.node.add_dependency(
                self.api_lambda.handler
            )



from typing import Optional, Mapping, Any, TypeVar, List

from pydantic import BaseModel, Extra
from aws_cdk import core, aws_ec2 as ec2, aws_secretsmanager as secretsmanager


class VpcConfig(BaseModel):
    cidr: str
    export_name: str


class HostedZoneConfig(BaseModel):
    domain_name: str
    export_name: str
    use_github_pages: bool = False


class NetworkConfig(BaseModel):
    vpc: VpcConfig
    hosted_zone: HostedZoneConfig


class SecretsConfig(BaseModel):
    name: str
    arn_key: str
    exclude_punctuation: bool = True
    include_space: bool = False
    password_length: int = 32

    class Config:
        extra = Extra.allow

    def create(self, *, scope: core.Construct) -> secretsmanager.Secret:
        return secretsmanager.Secret(
            scope,
            self.name,
            generate_secret_string=secretsmanager.SecretStringGenerator(
                exclude_punctuation=self.exclude_punctuation,
                include_space=self.include_space,
                password_length=self.password_length,
            ),
        )


class CanaryConfig(BaseModel):

    commit_sha: str
    version: str
    health_check_url: str

    class Config:
        extra = Extra.allow


class CustomResourceConfig(BaseModel):

    source_path: str
    properties: Mapping[str, Any]

    class Config:
        extra = Extra.allow


class ServiceConfig(BaseModel):
    domain_name: str
    project_source_path: str
    secrets: Optional[List[SecretsConfig]]
    environment: Optional[Mapping[str, Any]]
    health_check_url: Optional[str] = None
    pre_deploy_config: Optional[CustomResourceConfig] = None
    post_deploy_config: Optional[CustomResourceConfig] = None

    class Config:
        extra = Extra.allow


class RDSConfig(BaseModel):
    db_name: str
    db_username: str
    multi_az: bool = False
    deletion_protection: bool = False
    setup_alarms: bool = False
    instance_class: str = "BURSTABLE3"
    instance_size: str = "MICRO"

    class Config:
        extra = Extra.allow

    @property
    def instance_type(self) -> ec2.InstanceType:
        return ec2.InstanceType.of(
            getattr(ec2.InstanceClass, self.instance_class),
            getattr(ec2.InstanceSize, self.instance_size),
        )


class APIConfig(BaseModel):
    hosted_zone_domain_name: str
    cert_export_name: str
    version: str
    vpc_name: str
    rds_config: Optional[RDSConfig]
    service_config: Optional[ServiceConfig]

    class Config:
        extra = Extra.allow


class CertConfig(BaseModel):
    domain_name: str
    export_prefix: str = ""
    subdomains: Optional[List[str]] = None

    class Config:
        extra = Extra.allow


DataModelT = TypeVar("DataModelT")



from aws_cdk import core, aws_certificatemanager as acm, aws_route53 as route53

from acru_l.stacks.base import BaseStack
from acru_l.stacks.config import CertConfig


class CertificatesStack(BaseStack):
    config_class = CertConfig
    config: CertConfig

    def __init__(
        self,
        scope: core.Construct,
        id: str,
        env: core.Environment,
        **kwargs,
    ):
        super().__init__(scope, id, env=env, **kwargs)
        config = self.config
        subdomains = config.subdomains or []
        domain_name = config.domain_name
        export_prefix = config.export_prefix
        hosted_zone = route53.HostedZone.from_lookup(
            self, "HostedZone", domain_name=domain_name
        )
        main_cert = acm.DnsValidatedCertificate(
            self,
            "MainCertificate",
            domain_name=domain_name,
            hosted_zone=hosted_zone,
        )
        core.CfnOutput(
            self,
            "MainCertificateARN",
            value=main_cert.certificate_arn,
            export_name=f"{export_prefix.title()}MainCertificate",
        )
        wild_cert = acm.DnsValidatedCertificate(
            self,
            "WildCardCertificate",
            domain_name=f"*.{domain_name}",
            hosted_zone=hosted_zone,
        )
        core.CfnOutput(
            self,
            "WildCardCertificateARN",
            value=wild_cert.certificate_arn,
            export_name=f"{export_prefix.title()}WildCardCertificate",
        )
        for subdomain in subdomains:
            prefix_wild_cert = acm.DnsValidatedCertificate(
                self,
                f"{subdomain.title()}WildCardCertificate",
                domain_name=f"*.{subdomain.lower()}.{domain_name}",
                hosted_zone=hosted_zone,
            )
            _prefix = subdomain.title() + export_prefix.title()
            core.CfnOutput(
                self,
                f"{subdomain.title()}WildCardCertificateARN",
                value=prefix_wild_cert.certificate_arn,
                export_name=f"{_prefix}WildCardCertificate",
            )



from acru_l.resources.hosted_zone import HostedZone
from acru_l.resources.vpc import VPC
from acru_l.stacks.base import BaseStack
from aws_cdk import (
    core,
)

from acru_l.stacks.config import NetworkConfig


class NetworkStack(BaseStack):

    config_class = NetworkConfig
    config: NetworkConfig

    def __init__(
        self, scope: core.Construct, id: str, env: core.Environment, **kwargs
    ):
        super().__init__(scope, id, env=env, **kwargs)
        config = self.config
        VPC(
            self,
            "VPC",
            cidr=config.vpc.cidr,
            export_name=config.vpc.export_name,
        )
        HostedZone(
            self,
            "HostedZone",
            domain_name=config.hosted_zone.domain_name,
            export_name=config.hosted_zone.export_name,
            use_github_pages=config.hosted_zone.use_github_pages,
        )



from aws_cdk import (
    core,
)


class BaseStack(core.Stack):

    config_class = NotImplemented

    def __init__(
        self,
        scope: core.Construct,
        id: str,
        env: core.Environment,
        *,
        commit_sha: str,
        config,
        **kwargs
    ):
        super().__init__(scope, id, env=env, **kwargs)
        self.commit_sha = commit_sha
        self.config = config



from aws_cdk import (
    core,
    aws_ec2 as ec2,
    aws_certificatemanager as acm,
    aws_route53 as route53,
)

from acru_l.resources.rds.instances import PostgresInstance
from acru_l.services.wsgi import WSGIService
from acru_l.stacks.base import BaseStack
from acru_l.stacks.config import APIConfig, CanaryConfig


class LucarioStack(BaseStack):
    """
    WSGI
    POSTGRES
    LAMBDA
    API GATEWAY

    TODO: add REDIS

    Prerequisites:
    VPC
    HOSTED_ZONE
    CERTIFICATES
    """

    config_class = APIConfig
    config: APIConfig

    def __init__(
        self, scope: core.Construct, id: str, env: core.Environment, **kwargs
    ):
        super().__init__(scope, id, env=env, **kwargs)

        config = self.config
        vpc = ec2.Vpc.from_lookup(self, "VPC", vpc_name=config.vpc_name)
        hosted_zone = route53.HostedZone.from_lookup(
            self, "HostedZone", domain_name=config.hosted_zone_domain_name
        )

        db_config = config.rds_config
        database = PostgresInstance(
            self,
            f"{id}PG",
            db_name=db_config.db_name,
            db_username=db_config.db_username,
            vpc=vpc,
            multi_az=db_config.multi_az,
            deletion_protection=db_config.deletion_protection,
            instance_type=db_config.instance_type,
        )
        if db_config.setup_alarms:
            database.setup_alarms()

        # TODO: Add options for Redis Elasticache
        service_config = config.service_config
        environment_variables = service_config.environment or {}
        environment_variables.update(
            {
                "DB_NAME": database.db_name,
                "DB_USERNAME": database.db_username,
                "DB_HOST": database.endpoint_address,
                "DB_PORT": database.endpoint_port,
                "DB_SECRET_ID": database.creds.secret_arn,
            }
        )

        secret_arns = [database.creds.secret_arn]

        certificate = acm.Certificate.from_certificate_arn(
            self,
            f"{id}Certificate",
            core.Fn.import_value(config.cert_export_name),
        )
        canary_config = None
        if service_config.health_check_url:
            canary_config = CanaryConfig(
                commit_sha=self.commit_sha,
                version=config.version,
                health_check_url=service_config.health_check_url,
            )
        self.service = WSGIService(
            self,
            f"{id}Service",
            vpc=vpc,
            certificate=certificate,
            hosted_zone=hosted_zone,
            domain_name=service_config.domain_name,
            environment_variables=environment_variables,
            secret_arns=secret_arns,
            project_source_path=service_config.project_source_path,
            pre_deploy_config=service_config.pre_deploy_config,
            post_deploy_config=service_config.post_deploy_config,
            canary_config=canary_config,
            secrets=service_config.secrets,
        )



#!/usr/bin/env python3
import toml
from aws_cdk import (
    core,
)
from pydantic import BaseSettings
from pydantic.utils import import_string
from typing import Optional

# from acrul_toolkit.module_loading import import_string


class AppConfig(BaseSettings):
    AWS_ACCOUNT_ID: str
    AWS_REGION: str
    COMMIT_SHA: str
    CONFIG_FILE_PATH: str = "./acru_l.toml"

    class Config:
        case_sensitive = True


def setup_app(
    app: Optional[core.App] = None, app_config: Optional[AppConfig] = None
) -> core.App:
    app = app or core.App()
    app_config = app_config or AppConfig()
    env = core.Environment(
        account=app_config.AWS_ACCOUNT_ID, region=app_config.AWS_REGION
    )
    config_dict = toml.load(app_config.CONFIG_FILE_PATH)
    for stack in config_dict["stack"]:
        stack_class = import_string(stack["stack_class"])
        stack_config_class = stack_class.config_class
        stack_class(
            app,
            stack["name"],
            env=env,
            commit_sha=app_config.COMMIT_SHA,
            config=stack_config_class(**stack["config"]),
        )
    return app



import json

from aws_cdk import (
    core,
    aws_secretsmanager as secretsmanager,
    aws_ec2 as ec2,
    aws_logs as logs,
    aws_cloudwatch as cloudwatch,
    aws_rds as rds,
)


# TODO: add option for db proxy
# https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-rds.DatabaseProxy.html
# https://docs.aws.amazon.com/cdk/api/latest/docs/aws-rds-readme.html#creating-a-database-proxy
# https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-rds.DatabaseInstanceReadReplica.html
class RDSInstance(core.Construct):
    def __init__(
        self,
        scope: core.Construct,
        id: str,
        *,
        db_name: str,
        db_username: str,
        vpc: ec2.Vpc,
        engine: rds.IInstanceEngine,
        allocated_storage=20,
        deletion_protection: bool = False,
        port: int = 5432,
        instance_type: ec2.InstanceType = ec2.InstanceType.of(
            ec2.InstanceClass.BURSTABLE3,
            ec2.InstanceSize.MICRO,
        ),
        removal_policy: core.RemovalPolicy = core.RemovalPolicy.DESTROY,
        multi_az: bool = False,
        storage_type: rds.StorageType = rds.StorageType.STANDARD,
        storage_encrypted: bool = True,
        backup_retention: int = 1,
        monitoring_interval: int = 60,
        enable_performance_insights: bool = True,
        cloudwatch_logs_retention: logs.RetentionDays = logs.RetentionDays.ONE_MONTH,  # noqa: E501
        auto_minor_version_upgrade: bool = True,
    ):
        super().__init__(scope, id)
        self.id = id
        self.db_name = db_name
        self.db_username = db_username

        # Creates a security group for AWS RDS
        sg_rds = ec2.SecurityGroup(
            self,
            f"{id}SecurityGroup",
            vpc=vpc,
        )

        # Adds an ingress rule which allows resources in the VPC's CIDR
        # to access the database.
        sg_rds.add_ingress_rule(
            peer=ec2.Peer.ipv4(vpc.vpc_cidr_block),
            connection=ec2.Port.tcp(port),
        )
        self.creds = secretsmanager.Secret(
            self,
            f"{id}Credentials",
            generate_secret_string=secretsmanager.SecretStringGenerator(
                exclude_punctuation=True,
                include_space=False,
                generate_string_key="password",
                secret_string_template=json.dumps({"username": db_username}),
            ),
        )

        self.instance = rds.DatabaseInstance(
            self,
            f"{id}Instance",
            allocated_storage=allocated_storage,
            deletion_protection=deletion_protection,
            credentials=rds.Credentials.from_password(
                username=db_username,
                password=self.creds.secret_value_from_json("password"),
            ),
            security_groups=[sg_rds],
            database_name=db_name,
            engine=engine,
            vpc=vpc,
            port=port,
            instance_type=instance_type,
            removal_policy=removal_policy,
            multi_az=multi_az,
            storage_type=storage_type,
            storage_encrypted=storage_encrypted,
            backup_retention=core.Duration.days(backup_retention),
            monitoring_interval=core.Duration.seconds(monitoring_interval),
            enable_performance_insights=enable_performance_insights,
            cloudwatch_logs_retention=cloudwatch_logs_retention,
            auto_minor_version_upgrade=auto_minor_version_upgrade,
        )

    @property
    def vpc(self) -> ec2.Vpc:
        return self.instance.vpc

    @property
    def endpoint_port(self) -> str:
        return self.instance.db_instance_endpoint_port

    @property
    def endpoint_address(self) -> str:
        return self.instance.db_instance_endpoint_address

    def setup_alarms(self):
        cloudwatch.Alarm(
            self,
            f"{self.id}HighCPU",
            metric=self.instance.metric_cpu_utilization(
                unit=cloudwatch.Unit.PERCENT
            ),
            statistic="Average",
            threshold=80,
            evaluation_periods=2,
            period=core.Duration.minutes(5),
        )

        cloudwatch.Alarm(
            self,
            f"{self.id}HighSwapSpace",
            metric=self.instance.metric(
                "SwapUsage", unit=cloudwatch.Unit.BYTES
            ),
            statistic="Average",
            threshold=209715200,  # 200MB
            evaluation_periods=2,
            period=core.Duration.minutes(5),
            treat_missing_data=cloudwatch.TreatMissingData.NOT_BREACHING,
        )
        cloudwatch.Alarm(
            self,
            f"{self.id}HighReadLatency",
            metric=self.instance.metric(
                "ReadLatency", unit=cloudwatch.Unit.SECONDS
            ),
            statistic="Average",
            threshold=0.05,
            evaluation_periods=2,
            period=core.Duration.minutes(5),
            treat_missing_data=cloudwatch.TreatMissingData.NOT_BREACHING,
        )
        cloudwatch.Alarm(
            self,
            f"{self.id}HighWriteLatency",
            metric=self.instance.metric(
                "WriteLatency", unit=cloudwatch.Unit.SECONDS
            ),
            statistic="Average",
            threshold=0.05,
            evaluation_periods=2,
            period=core.Duration.minutes(5),
            treat_missing_data=cloudwatch.TreatMissingData.NOT_BREACHING,
        )
        cloudwatch.Alarm(
            self,
            f"{self.id}LowFreeStorage",
            metric=self.instance.metric_free_storage_space(
                unit=cloudwatch.Unit.BYTES
            ),
            threshold=1073741824,  # 1GB
            statistic="Average",
            evaluation_periods=2,
            period=core.Duration.minutes(5),
            comparison_operator=cloudwatch.ComparisonOperator.LESS_THAN_OR_EQUAL_TO_THRESHOLD,  # noqa: E501
        )
        cloudwatch.Alarm(
            self,
            f"{self.id}LowFreeMemory",
            metric=self.instance.metric_freeable_memory(
                unit=cloudwatch.Unit.BYTES
            ),
            threshold=104857600,  # 100MB
            evaluation_periods=2,
            period=core.Duration.minutes(5),
            statistic="Average",
            comparison_operator=cloudwatch.ComparisonOperator.LESS_THAN_OR_EQUAL_TO_THRESHOLD,  # noqa: E501
        )


class PostgresInstance(RDSInstance):
    def __init__(self, *args, **kwargs):
        kwargs["engine"] = rds.DatabaseInstanceEngine.POSTGRES
        super().__init__(*args, **kwargs)



from aws_cdk import (
    core,
    aws_route53 as route53,
)


class HostedZone(core.Construct):
    def __init__(
        self,
        scope: core.Construct,
        id: str,
        *,
        domain_name: str,
        export_name: str = "HostedZoneId",
        use_github_pages: bool = False,
    ):
        super().__init__(scope, id)

        self.hosted_zone = route53.HostedZone(
            self, "HostedZone", zone_name=domain_name
        )
        # Usage: core.Fn.import_value(export_name)
        core.CfnOutput(
            self,
            "HostedZoneId",
            value=self.hosted_zone.hosted_zone_id,
            export_name=export_name,
        )

        if use_github_pages:
            route53.ARecord(
                self,
                "GithubPagesRecord",
                zone=self.hosted_zone,
                record_name=f"{domain_name}.",
                target=route53.RecordTarget.from_ip_addresses(
                    "185.199.108.153",
                    "185.199.109.153",
                    "185.199.110.153",
                    "185.199.111.153",
                ),
            )
            route53.CnameRecord(
                self,
                "WWWRecord",
                zone=self.hosted_zone,
                record_name=f"www.{domain_name}.",
                domain_name=f"{domain_name}.",
            )



import os

from typing import List, Optional

from acru_l.resources.functions import PythonFunction
from acru_l.services.base import Service
from aws_cdk import (
    core,
    aws_lambda as _lambda,
    aws_lambda_python as lambda_python,
)

wsgi_dirname = os.path.dirname(__file__)


class WSGIService(Service):
    def __init__(
        self,
        scope: core.Construct,
        id: str,
        *,
        project_source_path: str,
        api_lambda_source_path: Optional[str] = None,
        **kwargs
    ):
        if not api_lambda_source_path:
            kwargs["api_lambda_source_path"] = os.path.join(
                wsgi_dirname, "src"
            )
        kwargs["function_class"] = PythonFunction
        super().__init__(
            scope, id, project_source_path=project_source_path, **kwargs
        )

    def package_project(
        self, *, source_path: str
    ) -> List[_lambda.LayerVersion]:
        package_layer = lambda_python.PythonLayerVersion(
            self,
            "ProjectLayer",
            entry=source_path,
            compatible_runtimes=[self.runtime],
        )
        return [package_layer]



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['acru_l',
 'acru_l.apps',
 'acru_l.resources',
 'acru_l.resources.canary',
 'acru_l.resources.canary.src',
 'acru_l.resources.rds',
 'acru_l.resources.ses',
 'acru_l.resources.ses.domain_validation',
 'acru_l.resources.ses.verified_emails',
 'acru_l.services',
 'acru_l.services.wsgi',
 'acru_l.services.wsgi.src',
 'acru_l.stacks']

package_data = \
{'': ['*'], 'acru_l.resources.ses': ['layer/*']}

install_requires = \
['acru-l-toolkit>=0.1.0,<0.2.0',
 'aws-cdk.aws-apigatewayv2-integrations==1.79.0',
 'aws-cdk.aws-apigatewayv2==1.79.0',
 'aws-cdk.aws-cloudfront==1.79.0',
 'aws-cdk.aws-dynamodb==1.79.0',
 'aws-cdk.aws-events-targets==1.79.0',
 'aws-cdk.aws-events==1.79.0',
 'aws-cdk.aws-lambda-nodejs==1.79.0',
 'aws-cdk.aws-lambda-python==1.79.0',
 'aws-cdk.aws-lambda==1.79.0',
 'aws-cdk.aws-rds==1.79.0',
 'aws-cdk.aws-route53==1.79.0',
 'aws-cdk.aws-s3==1.79.0',
 'aws-cdk.aws-secretsmanager==1.79.0',
 'aws-cdk.core==1.79.0',
 'aws-cdk.custom-resources==1.79.0',
 'environs>=9.2.0,<10.0.0',
 'pydantic>=1.7.3,<2.0.0']

setup_kwargs = {
    'name': 'acru-l',
    'version': '0.0.0',
    'description': '',
    'long_description': '# AWS Cloud Resource Utils - Library (ACRU-L)\n\nPronounced _Ah-crew-el (*ə-kroo͞′l*)_\n\nAn open source framework for collecting and reusing AWS CDK constructs and stacks.\n\n## Installation\n\n`poetry add -D acru-l`\n\n`pip install acru-l`\n\n## Usage\n\n\n## Core Concepts\n\n* Resources - Extended constructs\n* Services - Collections of Resources that build a service interface\n* Stacks - Collections of Services\n\n### Resources\nExtended constructs with set defaults\n\n### Services\n\nREAL (RDS-Elasticache-APIGateway-Lambda)\n\nLAD (Lambda-APIGateway-DynamoDB)\n\n### Stacks\nPostgres Redis REAL Stack\n\nGlobal LAD Stack',
    'author': 'Anthony Almarza',
    'author_email': 'anthony.almarza@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
